pub mod log;

use anyhow::{anyhow, Result};
use shared_memory::{Shmem, ShmemConf, ShmemError};

pub fn create_input_shared_memory(is_owner: bool) -> Result<Shmem> {
    let shmem_conf = ShmemConf::new().size(36).os_id("tasoller_input");
    let shmem_result = match shmem_conf.clone().create() {
        Ok(s) => Ok(s),
        Err(ShmemError::MappingIdExists) => shmem_conf.open(),
        Err(e) => {
            return Err(anyhow!(
                "Failed to create/open shared memory tasoller_input: {e:#}"
            ));
        }
    };

    shmem_result
        .map(|mut m| {
            m.set_owner(is_owner);
            m
        })
        .map_err(|e| anyhow!("Failed to create/open shared memory tasoller_input: {e:#}"))
}
